@@ -96,7 +96,7 @@ tab_df <- function(x,
                    footnote = NULL,
                    col.header = NULL,
                    show.type = FALSE,
-                   show.rownames = TRUE,
+                   show.rownames = FALSE,
                    show.footnote = FALSE,
                    alternate.rows = FALSE,
                    sort.column = NULL,
@@ -113,11 +113,7 @@ tab_df <- function(x,
   # get style definition
   style <- tab_df_style(CSS = CSS, ...)
 
-  if (obj_has_rownames(x)) {
-    rn <- rownames(x)
-  } else {
-    rn <- NULL
-  }
+  rnames <- row.names(x)
 
   x <- as.data.frame(lapply(x, function(.i) {
     if (is.numeric(.i) && sjmisc::is_float(.i))
@@ -126,10 +122,6 @@ tab_df <- function(x,
       .i
   }))
 
-  if (!is.null(rn)) {
-    rownames(x) <- rn
-  }
-
   # get HTML content
   page.content <- tab_df_content(
       mydf = x,
@@ -142,6 +134,7 @@ tab_df <- function(x,
       altr.row.col = alternate.rows,
       sort.column = sort.column,
       include.table.tag = TRUE,
+      rnames = rnames,
       ...
     )
 
@@ -185,10 +178,11 @@ tab_dfs <- function(x,
                     footnotes = NULL,
                     col.header = NULL,
                     show.type = FALSE,
-                    show.rownames = TRUE,
+                    show.rownames = FALSE,
                     show.footnote = FALSE,
                     alternate.rows = FALSE,
                     sort.column = NULL,
+                    digits = 2,
                     encoding = "UTF-8",
                     CSS = NULL,
                     file = NULL,
@@ -216,6 +210,13 @@ tab_dfs <- function(x,
   # get HTML content
   page.content <- paste(
       purrr::flatten_chr(purrr::pmap(list(x, titles, footnotes), function(dat, title, footnote) {
+        dat[] <- lapply(dat, function(.i) {
+          if (is.numeric(.i) && sjmisc::is_float(.i))
+            sprintf("%.*f", digits, .i)
+          else
+            .i
+        })
+
         tab_df_content(
           mydf = dat,
           title = title,
