@@ -139,11 +139,13 @@
 #' @param df.method,p.val Method for computing degrees of freedom for p-values,
 #'   standard errors and confidence intervals (CI). Only applies to mixed models.
 #'   Use \code{df.method = "wald"} for a faster, but less precise computation.
-#'   \code{df.method = "kenward"} (or \code{df.method = "kr"}) uses Kenward-Roger
-#'   approximation for the degrees of freedom. \code{df.method = "satterthwaite"}
-#'   uses Satterthwaite's approximation and \code{"ml1"} uses a "m-l-1" heuristic
-#'   see \code{\link[parameters]{degrees_of_freedom}} for details). Use
-#'   \code{show.df = TRUE} to show the approximated degrees of freedom
+#'   This will use the residual degrees of freedom (as returned by \code{df.residual()})
+#'   for linear mixed models, and \code{Inf} degrees if freedom for all other
+#'   model families. \code{df.method = "kenward"} (or \code{df.method = "kr"})
+#'   uses Kenward-Roger approximation for the degrees of freedom.
+#'   \code{df.method = "satterthwaite"} uses Satterthwaite's approximation and
+#'   \code{"ml1"} uses a "m-l-1" heuristic see \code{\link[parameters]{degrees_of_freedom}}
+#'   for details). Use \code{show.df = TRUE} to show the approximated degrees of freedom
 #'   for each coefficient.
 #' @param p.style Character, indicating if p-values should be printed as
 #'   numeric value (\code{"numeric"}), as 'stars' (asterisks) only (\code{"stars"}),
@@ -154,7 +156,7 @@
 #'    See 'Details' or \href{https://strengejacke.github.io/sjPlot/articles/table_css.html}{this package-vignette}.
 #' @param file Destination file, if the output should be saved as file.
 #'    If \code{NULL} (default), the output will be saved as temporary file and
-#'    openend either in the IDE's viewer pane or the default web browser.
+#'    opened either in the IDE's viewer pane or the default web browser.
 #' @param use.viewer Logical, if \code{TRUE}, the HTML table is shown in the IDE's
 #'    viewer pane. If \code{FALSE} or no viewer available, the HTML table is
 #'    opened in a web browser.
@@ -811,7 +813,7 @@ tab_model <- function(
       if (show.aic) aic <- model_aic(model)
 
       aicc <- NULL
-      if (show.aicc) aic <- model_aicc(model)
+      if (show.aicc) aicc <- model_aicc(model)
 
       loglik <- NULL
       if (show.loglik) loglik <- model_loglik(model)
@@ -1439,6 +1441,6 @@ format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold){
   dat$p.value[dat$p.value == pv] <- "&lt;0.001"
 
   pv <- paste0("<strong>0.", paste(rep("0", digits.p), collapse = ""), "</strong>")
-  dat$p.value[dat$p.value == pv] <- "<strong>&lt;0.001"
+  dat$p.value[dat$p.value == pv] <- "<strong>&lt;0.001</strong>"
   dat
 }
